@@ -5,7 +5,7 @@ import sys
 from typing import Callable, Dict, List, Any, Optional
 from uuid import UUID
 
-from omotes_sdk import streamcapture
+import streamcapture
 from billiard.einfo import ExceptionInfo
 from celery import Task as CeleryTask, Celery
 from celery.apps.worker import Worker as CeleryWorker
@@ -22,16 +22,6 @@ from omotes_sdk.types import ParamsDict
 logger = logging.getLogger("omotes_sdk_internal")
 
 
-class EarlySystemExit(Exception):
-    """Wrapper for `SystemExit` exception.
-
-    To ensure that the worker process does not shutdown but rather handles the `SystemExit` as an
-    error
-    """
-
-    ...
-
-
 class TaskUtil:
     """Utilities for a Celery task."""
 
@@ -67,6 +57,7 @@ class TaskUtil:
             message,
         )
         self.broker_if.send_message_to(
+            None,
             WORKER.config.task_progress_queue_name,
             TaskProgressUpdate(
                 job_id=str(self.job_id),
@@ -166,6 +157,7 @@ class WorkerTask(CeleryTask):
         if result_message:
             logger.debug("Sending result for job %s", job_id)
             self.broker_if.send_message_to(
+                None,
                 WORKER.config.task_result_queue_name,
                 result_message.SerializeToString(),
             )
@@ -217,10 +209,7 @@ def wrapped_worker_task(
     logger.info("Worker started new task %s", job_id)
     task_util = TaskUtil(job_id, task, task.broker_if)
     task_util.update_progress(0, "Job calculation started")
-    try:
-        task.output_esdl = WORKER_TASK_FUNCTION(input_esdl, params_dict, task_util.update_progress)
-    except SystemExit as e:
-        raise EarlySystemExit(e)
+    task.output_esdl = WORKER_TASK_FUNCTION(input_esdl, params_dict, task_util.update_progress)
 
     task_util.update_progress(1.0, "Calculation finished.")
 
@@ -228,8 +217,9 @@ def wrapped_worker_task(
 class Worker:
     """Worker which works as an Celery Worker application and runs a single type of task."""
 
-    config = WorkerConfig()
+    config: WorkerConfig
     """Configuration for the worker."""
+
     captured_logging_string = io.StringIO()
     """Captured logging while performing the task."""
 
@@ -238,6 +228,10 @@ class Worker:
     celery_worker: CeleryWorker
     """The Celery Worker app."""
 
+    def __init__(self) -> None:
+        """Instantiate Worker instance config attribute."""
+        self.config = WorkerConfig()
+
     def start(self) -> None:
         """Start the `Worker`.
 
@@ -259,6 +253,7 @@ class Worker:
         self.celery_app.conf.worker_prefetch_multiplier = 1
         self.celery_app.conf.broker_connection_retry_on_startup = True
         # app.conf.worker_send_task_events = True  # Tell the worker to send task events.
+        self.celery_app.conf.worker_hijack_root_logger = False
         self.celery_app.conf.worker_redirect_stdouts = False
 
         self.celery_app.task(wrapped_worker_task, base=WorkerTask, name=WORKER_TASK_TYPE, bind=True)
@@ -274,7 +269,7 @@ class Worker:
 
         self.celery_worker = self.celery_app.Worker(
             hostname=f"worker-{WORKER_TASK_TYPE}@{socket.gethostname()}",
-            log_level=logging.getLevelName(self.config.log_level),
+            loglevel=logging.getLevelName(self.config.log_level),
             autoscale=(1, 1),
         )
 
